@@ -3,20 +3,19 @@ package Fey::SQL::Fragment::Where::SubgroupStart;
 use strict;
 use warnings;
 
+use Moose;
 
 my $Paren = '(';
-sub new
-{
-    my $class = shift;
-
-    return bless \$Paren, $class;
-}
 
 sub sql
 {
     return $Paren;
 }
 
+no Moose;
+
+__PACKAGE__->meta()->make_immutable();
+
 
 1;
 
@@ -43,7 +42,7 @@ See L<Fey> for details on how to report bugs.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Copyright 2006-2009 Dave Rolsky, All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
